/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data IO Daemon module: FileItem Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: $
 *  Release: $Name:  $
 *
 */

#ifndef GLITE_DATA_IO_DAEMON_FILEITEM_HXX_
#define GLITE_DATA_IO_DAEMON_FILEITEM_HXX_

#include <string>

namespace glite{
namespace io   {
    
/**
 * FileItem class. This class  wrpas the File information and is used as 
 * parameter for the deamon plugins
 * @stereotype bean
 */
class FileItem {
public:

    /**
     * Constructor
     */
    FileItem(){
        m_guid = "00000000-0000-0000-0000-000000000000";
    }

    /**
     * Get the LFN Property
     * @return the LFN property
     */
    const char * getLFN() const { return m_lfn.c_str();}
    /**
     * Set the LFN Property
     * @param lfn [IN] the LFN value
     */
    void setLFN(const char * lfn) { m_lfn = lfn;}

    /**
     * Get the GUID Property
     * @return the GUID property
     */
    const char * getGUID()const {return m_guid.c_str();}
    /**
     * Set the GUID Property
     * @param guid [IN] the GUID value
     */
    void setGUID(const char * guid){m_guid.assign(guid);}

    /**
     * Get the SURL Property
     * @return the SURL property
     */
    const char * getSURL()const { return m_surl.c_str(); }
    /**
     * Set the SURL Property
     * @param surl [IN] the SURL value
     */
    void setSURL(const char * surl) { m_surl = surl;}

    /**
     * Get the TURL Property
     * @return the TURL property
     */
    const char * getTURL() const { return m_turl.c_str();}
    /**
     * Set the TURL Property
     * @param turl [IN] the TURL value
     */
    void setTURL(const char * turl) { m_turl = turl; }

    /**
     * Get the Permissions Property
     * @return the Permissions property
     */
    int getPermissions() const {return m_permissions;}
    /**
     * Set the Permissions Property
     * @param permissions [IN] the Permissions value
     */
    void setPermissions(int permissions) {m_permissions = permissions;}

    /**
     * Get the Size Property
     * @return the Size property
     */
    long long getSize() const {return m_size;}
    /**
     * Set the Size Property
     * @param size [IN] the Size value
     */
    void setSize(long long size) {m_size = size;}

private:

    /**
     * The LFN Property
     */
    std::string m_lfn;
    
    /**
     * The GUID Property
     */
    std::string m_guid;
    
    /**
     * The SURL Property
     */
    std::string m_surl;
    
    /**
     * The TURL Property
     */
    std::string m_turl;

    /**
     * The Permissions Property
     */
    int         m_permissions;

    /**
     * The Size Property
     */
    long long   m_size;
};


} // End namespace io
} // End namespace glite
    
#endif //GLITE_DATA_IO_DAEMON_FILEITEM_HXX_
