/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data IO Daemon module: FileStat Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: FileStat.hxx,v 1.2 2004/11/03 16:17:55 badino Exp $
 *  Release: $Name: glite-data-io-daemon_R_2_0_2 $
 *
 */

#ifndef GLITE_DATA_IO_DAEMON_FILESTAT_HXX_
#define GLITE_DATA_IO_DAEMON_FILESTAT_HXX_

#include <string>

namespace glite{
namespace io   {
    
/**
 * FileItem class. This class wraps the File information and is used as 
 * parameter for the deamon plugins
 * @stereotype bean
 */
class FileStat {
public:

    /**
     * Constructor
     */
    FileStat():
        m_mode(0),
        m_size(0),
        m_lastChange(0){
    }

    /**
     * Get the Mode Property
     * @return the Mode property
     */
    int getMode() const {return m_mode;}
    /**
     * Set the Mode Property
     * @param mode [IN] the Mode value
     */
    void setMode(int mode) {m_mode = mode;}

    /**
     * Get the Size Property
     * @return the Size property
     */
    long long getSize() const {return m_size;}
    /**
     * Set the Size Property
     * @param size [IN] the Size value
     */
    void setSize(long long size) {m_size = size;}

	/**
     * Get the File Owner
     * @return the File Owner
     */
    const char * getOwner() const {return m_owner.c_str();}
    /**
     * Set the File Owner
     * @param owner [IN] the File Owner
     */
    void setOwner(const char * owner) {m_owner = owner;}

	/**
     * Get the File Group
     * @return the File Group
     */
    const char * getGroup() const {return m_group.c_str();}
    /**
     * Set the File Group
     * @param group [IN] the File group
     */
    void setGroup(const char * group) {m_group = group;}

    /**
     * Get the Last Change Time Property
     * @return the Last Change Time Property
     */
	time_t getLastChangeTime() const { return m_lastChange;}
	/**
     * Set the Last Change Time Property
     * @param last_change [IN] the time to be set
     */
    void setLastChangeTime(time_t last_change) { m_lastChange = last_change;}

private:

    /**
     * The Mode Property
     */
    int m_mode;

    /**
     * The Size Property
     */
    long long m_size;
	
	/**
     * The File Owner Property
     */
    std::string m_owner;

	/**
     * The File Group Property
     */
    std::string m_group;
    
    /**
     * The Last Change Time Property
     */
    time_t m_lastChange;
};


} // End namespace io
} // End namespace glite
    
#endif //GLITE_DATA_IO_DAEMON_FILEITEM_HXX_
