/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data IO Daemon module: UserPrincipal Class
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: $
 *  Release: $Name:  $
 *
 *  Revision history:
 *  $Log: $
 *
 */

#ifndef GLITE_DATA_IO_DAEMON_USERPRINCIPAL_HXX_
#define GLITE_DATA_IO_DAEMON_USERPRINCIPAL_HXX_

#include <string>
#include <vector>

namespace glite{
namespace io   {
    
/**
 * UserPrincipal class. This class wraps the USer Principal information and is 
 * used as parameter for the deamon plugins
 * @stereotype bean 
 */
class UserPrincipal {

public:
    
    /**
     * Constructor
     */
    UserPrincipal(){}
    
    /**
     * Destructor
     */
    ~UserPrincipal(){}
    
    /**
     * Get the User's Name Property
     * @return the User's Name Property
     */
    const char * getName() const { return _name.c_str();}

    /**
     * Set the User's Name Property
     * @param name [IN] the User's Name value
     */
    void setName(const char * name){_name = name;}

    /**
     * Get the User's Distinguished Name Property
     * @return the User's Distinguished Name Property
     */
    const char * getDN() const {return _DN.c_str();}
    /**
     * Set the User's Distinguished Name Property
     * @param name [IN] the User's Distinguished Name value
     */
    void setDN(const char * dn) {_DN = dn;}

    /**
     * Get the User's Groups count
     * @return the User's Groups count
     */
    unsigned int getGroupsCount() const {return _groups.size();}
    /**
     * Get the User's Group name
     * @param i [IN] the position in the Users' group list
     * @return the Group name
     */
    const char * getGroupAt(unsigned int i) const {return _groups.at(i).c_str();}
    /**
     * Add a Grousp into the User's Group List
     * @param name [IN] the Group Name
     */
    void addGroup(const char * name) {_groups.push_back(name);}

    /**
     * Get the name of the file where the User's Proxy Credentails are stored
     * @return the name of the file where the User's Proxy Credentails
     * are stored
     */
    const char * getProxy() const { return _proxyName.c_str();}

    /**
     * Set the name of the file where the User's Proxy Credentails are stored
     * @param name [IN] the name of the file where the User's Proxy Credentails 
     * are stored
     */
    void setProxy(const char * filename){_proxyName = filename;}
    
private:
    /**
     * The Name Property
     */
    std::string _name;
    /**
     * The Distinguished Name Property
     */
    std::string _DN;
    /**
     * The User's Groups
     */
    std::vector<std::string> _groups;
    /**
     * The User's Credentials Proxy
     */
    std::string _proxyName;
};

} // End namespace io
} // End namespace glite
    
#endif //GLITE_DATA_IO_DAEMON_USERPRINCIPAL_HXX_
