/*
 *      Copyright (c) 2004 on behalf of the EU EGEE Project:
 *      The European Organization for Nuclear Research (CERN),
 *      Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *      Datamat Spa, Italy
 *      Centre National de la Recherche Scientifique (CNRS), France
 *      CS Systeme d'Information (CSSI), France
 *      Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *      Universiteit van Amsterdam (UvA), Netherlands
 *      University of Helsinki (UH.HIP), Finland
 *      University of Bergen (UiB), Norway
 *      Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 *
 *      GLite Data IO Daemon module: FileAccess plugin Repository
 *
 *      Authors: Paolo Badino <paolo.badino@cern.ch>
 *      Version info: $Id: $
 *      Release: $Name:  $
 *
 *      Revision history:
 *      $Log: $
 *
 */

#ifndef GLITE_DATA_IO_FILEACCESSREPOSIOTRY_HXX
#define GLITE_DATA_IO_FILEACCESSREPOSIOTRY_HXX

#include "glite/data/io/daemon/fileaccess/IFileAccess.hxx"
#include <map>
#include <string>

namespace log4cpp{
    class Category;
}

namespace glite{
namespace io{

/**
 * Repository for the File Access plugin. When a plugin is created, it should 
 * register itself on the FileAccessRepository.
 * @stereotype singleton
 */
class FileAccessRepository {
public:

    /**
     * Returns Singleton Instance
     * @return Singleton Instance
     */
    static FileAccessRepository * instance();

    /**
     * Register a plugin
     * @param plugin [IN] the plugin to register
     */
    void add(IFileAccess* plugin);

    /**
     * Deregister a plugin
     * @param plugin [IN] the plugin to remove
     */
    void erase(IFileAccess* plugin);
    
    /**
     * Returns the plugin with the given name
     * @param name [IN] the name of the requested plugin, or 0 if the default 
     * one should be returned
     * @return the plugin with the given name, the default one, or 0 if not 
     * available
     */
    IFileAccess* get(const char * name = 0) const;

protected:
    /**
     * Constructor
     */
    FileAccessRepository();

    /**
     * Destructor
     */
    ~FileAccessRepository();

private:

    /**
     * The Plugins
     */
    typedef std::map<std::string, IFileAccess*> PluginMap;

    /**
     * Singleton instance
     */
    static FileAccessRepository * _instance;
    
    /**
     * The logger
     */
    log4cpp::Category& _logger;
        
    /**
     * The Plugins
     */
    PluginMap  _plugins;

    /**
     * The Default Plugin
     */
    IFileAccess* _defaultPlugin;
};

} // End namespace io
} // End namespace glite

#endif //GLITE_DATA_IO_FILEACCESSREPOSIOTRY_HXX
