/*
 *      Copyright (c) 2004 on behalf of the EU EGEE Project:
 *      The European Organization for Nuclear Research (CERN),
 *      Istituto Nazionale di Fisica Nucleare (INFN), Italy
 *      Datamat Spa, Italy
 *      Centre National de la Recherche Scientifique (CNRS), France
 *      CS Systeme d'Information (CSSI), France
 *      Royal Institute of Technology, Center for Parallel Computers (KTH-PDC), Sweden
 *      Universiteit van Amsterdam (UvA), Netherlands
 *      University of Helsinki (UH.HIP), Finland
 *      University of Bergen (UiB), Norway
 *      Council for the Central Laboratory of the Research Councils (CCLRC), United Kingdom
 *
 *      GLite Data IO Daemon module: IFileAccess Interface
 *
 *      Authors: Paolo Badino <paolo.badino@cern.ch>
 *      Version info: $Id: $
 *      Release: $Name:  $
 *
 *      Revision history:
 *      $Log: $
 *
 */

#ifndef GLITE_DATA_IO_DAEMON_IFILEACCESS_HXX
#define GLITE_DATA_IO_DAEMON_IFILEACCESS_HXX

#include "glite/data/io/daemon/UserPrincipal.hxx"
#include "glite/data/io/daemon/FileItem.hxx"

namespace glite{
namespace io{
   
/**
 * Base class for the File Access plugin. To create a plugin, you must 
 * implement that interface and register it to the FileAccessRepository
 * @interface
 */
class IFileAccess {
public:

    /**
     * The grant return values
     */
    enum {
        ACCESS_GRANTED = 0,
        ACCESS_DENIED  = 1,
        ACCESS_ERROR   = -1
    };
     
    /**
     * The permission that should be checked
     */
    enum {
        MODE_EXECUTE  = 0x00000001,
        MODE_WRITE    = 0x00000002,
        MODE_READ     = 0x00000004,
        MODE_CREATE   = 0x00000008,// Special Flag used to check permissions to create the file
        MODE_DELETE   = 0x00000010 // Special Flag used to check permissions to delete the file
    };

     /**
     * Get the error message string
     * @return a string with the error description, if any
     * @return an empty string ("") if no error detected
     */
    virtual std::string  getErrorMessage() const {return "";}

    /**
     * Return the Plug-in Name
     * @return the Plug-in Name
     */
    virtual const char * getType() const = 0;

    /**
     * Grant or deny Access to the specific User.
     * @param f [IN] the FileItem object that contains the file information
     * @param u [IN] the UserPrincipal object that contains user information. It 
     * may be used for delegating credentials
     * @param mode [IN] the requested permission that should be granted. Should 
     * be a combination of MODE_READ , MODE_WRITE, MODE_EXECUTE, MODE_CREATE
     * @return ACCESS_GRANTED if success
     */
    virtual int grant(const FileItem * f, const UserPrincipal * u, int mode) = 0;

private:

    /** @link dependency */
    /*# UserPrincipal lnkUserPrincipal; */

    /** @link dependency */
    /*# FileItem lnkFileItem; */
};

} // End namespace io
} // End namespace glite


#endif //GLITE_DATA_IO_DAEMON_IFILEACCESS_HXX
