/*
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data IO Daemon module: FileResolve plugin Repository
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>
 *  Version info: $Id: $
 *  Release: $Name:  $
 *
 */

#ifndef GLITE_DATA_IO_DAEMON_FILERESOLVEREPOSITORY_HXX_
#define GLITE_DATA_IO_DAEMON_FILERESOLVEREPOSITORY_HXX_

#include "glite/data/io/daemon/fileresolve/IFileResolve.hxx"
#include <map>
#include <string>

namespace log4cpp{
    class Category;
}

namespace glite  {
namespace io     {
namespace resolve{

/**
 * Repository for the File Resolve plugin. When a plugin is created, it should 
 * register itself on the FileResolveRepository.
 * @stereotype singleton
 */
class FileResolveRepository {
public:

    /**
     * Returns Singleton Instance
     * @return Singleton Instance
     */
    static FileResolveRepository * instance();

    /**
     * Register a plugin
     * @param plugin [IN] the plugin to register
     */
    void add(IFileResolve* plugin);

    /**
     * Deregister a plugin
     * @param plugin [IN] the plugin to remove
     */
    void erase(IFileResolve* plugin);
    
    /**
     * Returns the plugin with the given name
     * @param name [IN] the name of the requested plugin, or 0 if the default 
     * one should be returned
     * @return the plugin with the given name, the default one, or 0 if not 
     * available
     */
    IFileResolve* get(const char * name = 0) const;

protected:
    /**
     * Constructor
     */
    FileResolveRepository();

    /**
     * Destructor
     */
    ~FileResolveRepository();

private:

    /**
     * The Plugins
     */
    typedef std::map<std::string, IFileResolve*> PluginMap;

    /**
     * Singleton instance
     */
    static FileResolveRepository * _instance;
    
    /**
     * The logger
     */
    log4cpp::Category& _logger;
    
    /**
     * The Plugins
     */
    PluginMap  _plugins;

    /**
     * The Default Plugin
     */
    IFileResolve* _defaultPlugin;
};

} // End namespace resolve
} // End namespace io
} // End namespace glite


#endif //GLITE_DATA_IO_DAEMON_FILERESOLVEREPOSITORY_HXX_
